@@ -28,6 +28,26 @@ typedef uint64_t jack_uuid_t;
 
 typedef int32_t jack_shmsize_t;
 
+#ifndef POST_PACKED_STRUCTURE
+#ifdef __GNUC__
+/* POST_PACKED_STRUCTURE needs to be a macro which
+   expands into a compiler directive. The directive must
+   tell the compiler to arrange the preceding structure
+   declaration so that it is packed on byte-boundaries rather
+   than use the natural alignment of the processor and/or
+   compiler.
+*/
+#ifdef __arm__
+#  define POST_PACKED_STRUCTURE
+#else
+#  define POST_PACKED_STRUCTURE __attribute__((__packed__))
+#endif /* ARM */
+#else
+/* Add other things here for non-gcc platforms */
+#endif
+#endif
+
+
 /**
  * Type used to represent sample frame counts.
  */
@@ -260,8 +280,6 @@ typedef enum JackLatencyCallbackMode jack_latency_callback_mode_t;
  *
  * @param mode playback or capture latency
  * @param arg pointer to a client supplied data
- *
- * @return zero on success, non-zero on error
  */ 
 typedef void (*JackLatencyCallback)(jack_latency_callback_mode_t mode, void *arg);
 
